@@ -43,7 +43,7 @@ public:
     QString essid;
     QString key;
 };
-class WifiSink : public QObject, public PluginAction
+class WifiSink : public PluginAction
 {
     Q_OBJECT
 public:
@@ -51,8 +51,9 @@ public:
 
     QString getName() { return "Wifi sink plugin"; }
     QString getText();
-    bool isReady();
     void clickAction(QWidget *parentWindow);
+signals:
+    void isReady();
 
 private slots:
     void barcodeAnalysed(QString barcodeType, QString barcodeData);
